# 💭 prompted | (*formerly `chatspec`)

A tiny & rapid prototyping library for working with the *OpenAI Chat Completions*,
*Google A2A* & *Anthropic Model Context Protocol* protocols.

> `prompted` is not *"ground-up"* framework, and uses external dependencies for generating completions & agentic functionality.
> This library was built for my own personal use, but provides an interface that is incredibly simple to master & understand. 


